# Generated by Django 2.1.7 on 2020-08-05 20:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0028_auto_20200805_1650'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bula',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-31 18:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0011_auto_20200728_1746'),
    ]

    operations = [
        migrations.AddField(
            model_name='cep',
            name='tipo_cep',
            field=models.CharField(max_length=200, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-17 13:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0011_auto_20200717_1040'),
    ]

    operations = [
        migrations.RenameField(
            model_name='filial',
            old_name='codigo',
            new_name='cd_filial',
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-15 22:28

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0004_auto_20200715_1925'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='precolista',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='precolista',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='precolista',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='produto',
            name='id',
        ),
        migrations.AddField(
            model_name='produto',
            name='altura_ecommerce',
            field=models.DecimalField(decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='categoria_principal',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='categoria_principal', to='produto.Categoria'),
        ),
        migrations.AddField(
            model_name='produto',
            name='cd_externo',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='cd_produto',
            field=models.IntegerField(default=1, primary_key=True, serialize=False),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='produto',
            name='descricao',
            field=models.TextField(null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='descricao_ecommerce',
            field=models.TextField(null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='imagem',
            field=models.FileField(default='produtos/caixa-nissei.jpg', upload_to='produtos'),
        ),
        migrations.AddField(
            model_name='produto',
            name='is_ecommerce',
            field=models.BooleanField(default=True, null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='is_pbm',
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='is_retencao_receita',
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='is_venda_controlada',
            field=models.BooleanField(default=False, null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='largura_ecommerce',
            field=models.DecimalField(decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='marca',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='marca', to='produto.Marca'),
        ),
        migrations.AddField(
            model_name='produto',
            name='marca_ecommerce',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='marca_ecommerce', to='produto.Marca'),
        ),
        migrations.AddField(
            model_name='produto',
            name='nm_ecommerce',
            field=models.CharField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='peso_ecommerce',
            field=models.DecimalField(decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AddField(
            model_name='produto',
            name='produto_pai',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AddField(
            model_name='produto',
            name='profundidade_ecommerce',
            field=models.DecimalField(decimal_places=2, max_digits=14, null=True),
        ),
        migrations.DeleteModel(
            name='PrecoLista',
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-17 13:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0007_auto_20200716_1451'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cep',
            name='id',
        ),
        migrations.AlterField(
            model_name='cep',
            name='cep',
            field=models.CharField(default=1, max_length=10, primary_key=True, serialize=False),
            preserve_default=False,
        ),
    ]



from django.http import JsonResponse
from django.views import View

from core.util.core import Inteliger


class InteligerView(View):
    def get(self, request, *args, **kwargs):
        Inteliger().atualizar_tempo_query()
        return JsonResponse({'status': 'Sistema atualizado com sucesso!'}, safe=False)



from core.views import Inteliger

class LogMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        response = self.get_response(request)
        Inteliger().salvar_log(request=request, response=response)
        return response
